---
id: mqtt
title: MQTT
---

These are the MQTT messages generated by Frigate. The default topic_prefix is `frigate`, but can be changed in the config file.

### `frigate/available`

Designed to be used as an availability topic with Home Assistant. Possible message are:
"online": published when frigate is running (on startup)
"offline": published right before frigate stops

### `frigate/<camera_name>/<object_name>`

Publishes the count of objects for the camera for use as a sensor in Home Assistant.

### `frigate/<zone_name>/<object_name>`

Publishes the count of objects for the zone for use as a sensor in Home Assistant.

### `frigate/<camera_name>/<object_name>/snapshot`

Publishes a jpeg encoded frame of the detected object type. When the object is no longer detected, the highest confidence image is published or the original image
is published again.

The height and crop of snapshots can be configured in the config.

### `frigate/events`

Message published for each changed event. The first message is published when the tracked object is no longer marked as a false_positive. When frigate finds a better snapshot of the tracked object or when a zone change occurs, it will publish a message with the same id. When the event ends, a final message is published with `end_time` set.

```json
{
  "type": "update", // new, update, end or clip_ready
  "before": {
    "id": "1607123955.475377-mxklsc",
    "camera": "front_door",
    "frame_time": 1607123961.837752,
    "snapshot_time": 1607123961.837752,
    "label": "person",
    "top_score": 0.958984375,
    "false_positive": false,
    "start_time": 1607123955.475377,
    "end_time": null,
    "score": 0.7890625,
    "box": [424, 500, 536, 712],
    "area": 23744,
    "region": [264, 450, 667, 853],
    "current_zones": ["driveway"],
    "entered_zones": ["yard", "driveway"],
    "thumbnail": null
  },
  "after": {
    "id": "1607123955.475377-mxklsc",
    "camera": "front_door",
    "frame_time": 1607123962.082975,
    "snapshot_time": 1607123961.837752,
    "label": "person",
    "top_score": 0.958984375,
    "false_positive": false,
    "start_time": 1607123955.475377,
    "end_time": null,
    "score": 0.87890625,
    "box": [432, 496, 544, 854],
    "area": 40096,
    "region": [218, 440, 693, 915],
    "current_zones": ["yard", "driveway"],
    "entered_zones": ["yard", "driveway"],
    "thumbnail": null
  }
}
```

### `frigate/stats`

Same data available at `/api/stats` published at a configurable interval.

### `frigate/<camera_name>/detect/set`

Topic to turn detection for a camera on and off. Expected values are `ON` and `OFF`.

### `frigate/<camera_name>/detect/state`

Topic with current state of detection for a camera. Published values are `ON` and `OFF`.

### `frigate/<camera_name>/clips/set`

Topic to turn clips for a camera on and off. Expected values are `ON` and `OFF`.

### `frigate/<camera_name>/clips/state`

Topic with current state of clips for a camera. Published values are `ON` and `OFF`.

### `frigate/<camera_name>/snapshots/set`

Topic to turn snapshots for a camera on and off. Expected values are `ON` and `OFF`.

### `frigate/<camera_name>/snapshots/state`

Topic with current state of snapshots for a camera. Published values are `ON` and `OFF`.
